import express, {Request, Response} from 'express';
import {model, Schema, connect, Document, HydratedDocument} from 'mongoose';

const router = express.Router();

interface IArtist {
  name: string;
  image?: File;
  description: string;
}

const artistSchema = new Schema<IArtist>({
  name: {
    type: String,
    required: true,
  },
  image: {
    type: Buffer,
  },
  description: {
    type: String,
    required: true,
  },
});

const Artist = model<IArtist>('Artist', artistSchema);

const run = async () => {
  await connect(`${process.env.MONGO_URL}/artist`);
};

run().catch((err) => console.log(err));

router.get('/', (req: Request, res: Response) => {
  return res.send('Hello');
});

router.post('/', async (req: Request, res: Response) => {
  const artist: HydratedDocument<IArtist> = new Artist({
    name: req.body.name,
    description: req.body.description,
  });
  await artist.save();
  res.send(artist);
});

export {router as artistRouter};
